gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r28309 - gnunet/src/mesh


From: gnunet
Subject: [GNUnet-SVN] r28309 - gnunet/src/mesh
Date: Wed, 24 Jul 2013 16:41:26 +0200

Author: bartpolot
Date: 2013-07-24 16:41:26 +0200 (Wed, 24 Jul 2013)
New Revision: 28309

Modified:
   gnunet/src/mesh/mesh_protocol_enc.h
Log:
- new connection messages


Modified: gnunet/src/mesh/mesh_protocol_enc.h
===================================================================
--- gnunet/src/mesh/mesh_protocol_enc.h 2013-07-24 14:14:03 UTC (rev 28308)
+++ gnunet/src/mesh/mesh_protocol_enc.h 2013-07-24 14:41:26 UTC (rev 28309)
@@ -42,7 +42,7 @@
 GNUNET_NETWORK_STRUCT_BEGIN
 
 /**
- * Message for mesh path creation.
+ * Message for mesh connection creation.
  */
 struct GNUNET_MESH_ConnectionCreate
 {
@@ -55,7 +55,7 @@
   struct GNUNET_MessageHeader header;
 
     /**
-     * Global id of the connection.
+     * ID of the connection for that tunnel.
      */
   uint32_t cid GNUNET_PACKED;
 
@@ -70,7 +70,6 @@
   uint32_t reserved GNUNET_PACKED;
 
     /**
-     * TODO do not add the first hop
      * path_length structs defining the *whole* path from the origin [0] to the
      * final destination [path_length-1].
      */
@@ -78,12 +77,12 @@
 };
 
 /**
- * Message for ack'ing a path
+ * Message for ack'ing a connection
  */
 struct GNUNET_MESH_ConnnectionACK
 {
     /**
-     * Type: GNUNET_MESSAGE_TYPE_MESH_PATH_ACK
+     * Type: GNUNET_MESSAGE_TYPE_MESH_CONNECTION_ACK
      */
   struct GNUNET_MessageHeader header;
 
@@ -93,20 +92,10 @@
   uint32_t cid GNUNET_PACKED;
 
     /**
      * OID of the tunnel
      */
-  struct GNUNET_PeerIdentity oid;
+  struct GNUNET_PeerIdentity tid;
 
-    /**
-     * ID of the endpoint
-     */
-  struct GNUNET_PeerIdentity peer_id;
-
-    /**
-     * Initial ACK value for payload.
-     */
-  uint32_t ack GNUNET_PACKED;
-
   /* TODO: signature */
 };
 
@@ -93,20 +92,10 @@
 
     /**
-     * OID of the tunnel
+     * TID of the tunnel
      */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]